@@ -3,13 +3,12 @@ import torch
 from pytorch_optimizer.utils import unit_norm
 
 
-def agc(p, agc_eps: float, agc_clip_val: float, eps: float = 1e-6):
-    """clip gradient values in excess of the unit-wise norm.
+def agc(p: torch.Tensor, agc_eps: float, agc_clip_val: float, eps: float = 1e-6):
+    """Clip gradient values in excess of the unit-wise norm.
     :param p: parameter.
     :param agc_eps: float.
     :param agc_clip_val: float.
-    :param eps: float. simple stop from div by zero
-        and no relation to standard optimizer eps
+    :param eps: float. simple stop from div by zero and no relation to standard optimizer eps
     """
     p_norm = unit_norm(p).clamp_(agc_eps)
     g_norm = unit_norm(p.grad)
