@@ -2,10 +2,14 @@ from typing import Optional, Tuple, Union
 
 import torch
 
+from pytorch_optimizer.types import PARAMETERS
 
-def normalize_gradient(
-    x: torch.Tensor, use_channels: bool = False, epsilon: float = 1e-8
-) -> torch.Tensor:
+
+def is_valid_parameters(parameters: PARAMETERS) -> bool:
+    return isinstance(parameters, (list, tuple)) and len(parameters) > 0 and isinstance(parameters[0], dict)
+
+
+def normalize_gradient(x: torch.Tensor, use_channels: bool = False, epsilon: float = 1e-8) -> torch.Tensor:
     """normalize gradient with stddev
     :param x: torch.Tensor. gradient.
     :param use_channels: bool. channel-wise normalization.
@@ -13,7 +17,6 @@ def normalize_gradient(
     :return: torch.Tensor. normalized gradient.
     """
     size: int = x.dim()
-
     if size > 1 and use_channels:
         s = x.std(dim=tuple(range(1, size)), keepdim=True) + epsilon
         x.div_(s)
